Stan Math Library: stan/math/rev/mat/fun/quad_form_sym.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
quad_form_sym.hpp File Reference
`#include <boost/utility/enable_if.hpp>`
`#include <boost/type_traits.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/fun/value_of.hpp>`
`#include <stan/math/prim/mat/fun/quad_form.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/mat/err/check_symmetric.hpp>`
`#include <stan/math/rev/mat/fun/quad_form.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename TA , int RA, int CA, typename TB , int RB, int CB>
boost::enable_if_c< boost::is_same< TA, var >::value||boost::is_same< TB, var >::value, Eigen::Matrix< var, CB, CB > >::type | stan::math::quad_form_sym (const Eigen::Matrix< TA, RA, CA > &A, const Eigen::Matrix< TB, RB, CB > &B)
template<typename TA , int RA, int CA, typename TB , int RB>
boost::enable_if_c< boost::is_same< TA, var >::value||boost::is_same< TB, var >::value, var >::type | stan::math::quad_form_sym (const Eigen::Matrix< TA, RA, CA > &A, const Eigen::Matrix< TB, RB, 1 > &B)

[ Stan Home Page ] © 2011–2016, Stan Development Team.